Widgets
-------

.. toctree::
   :maxdepth: 1

   widgets/databases_update.md
   widgets/geo_data_sets.md
   widgets/dicty_express.md
   widgets/genes.md
   widgets/differential_expression.md
   widgets/go_browser.md
   widgets/kegg_pathways.md
   widgets/gene_set_enrichment.md
   widgets/cluster_analysis.md
   widgets/volcano_plot.md
   widgets/marker_genes.md
   widgets/annotate_projection.md